==> prestashop_1.5.0.13.zip: prestashop/modules/editorial/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{editorial}prestashop>editorial_a46dcd3561c3feeb53903dfc0f796a35'] = 'Startseiten-Text-Editor';
$_MODULE['<{editorial}prestashop>editorial_d02076897ed05399e22a0597404924ad'] = 'Ein Texteditor-Modul für Ihre Startseite';
$_MODULE['<{editorial}prestashop>editorial_0245625ee10f9c6c0ed7f50eb1838856'] = 'Haupttitel';
$_MODULE['<{editorial}prestashop>editorial_7496c27605d7ac3462a5dab8ecf1b569'] = 'Erscheint oben auf der Startseite';
$_MODULE['<{editorial}prestashop>editorial_e1f46be647e598f00eeb0ab62561d695'] = 'Untertitel';
$_MODULE['<{editorial}prestashop>editorial_bf75f228011d1443c4ea7aca23c3cff2'] = 'Einleitungstext';
$_MODULE['<{editorial}prestashop>editorial_930919b6f854a62e62401e3e76377cc1'] = 'Text Ihrer Wahl, zum Beispiel erläutern Sie Ihre Mission, heben ein neues Produkt hervor oder beschreiben ein aktuelles Ereignis';
$_MODULE['<{editorial}prestashop>editorial_78587f196180054fcb797d40f4a86f10'] = 'Logo der Startseite';
$_MODULE['<{editorial}prestashop>editorial_28d74ee805e3a162047d8f917b74dcb3'] = 'Startseitenlogo-Link';
$_MODULE['<{editorial}prestashop>editorial_98039e8f2a0d93fc0fff503f9166f59b'] = 'Startseitenlogo Untertitel';
$_MODULE['<{editorial}prestashop>editorial_7fc8b5e7597368c070f5bc87c719dcc1'] = 'Sie können diese Handlung nicht ausführen';
$_MODULE['<{editorial}prestashop>editorial_07b8c09e490f7afbdcfa9cd5bfcfd4a9'] = 'Ein Fehler trat beim Hochladen des Bilds auf.';
$_MODULE['<{editorial}prestashop>editorial_462390017ab0938911d2d4e964c0cab7'] = 'Einstellungen erfolgreich aktualisiert';

==> prestashop_1.5.2.0.zip: prestashop/modules/editorial/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{editorial}prestashop>editorial_a46dcd3561c3feeb53903dfc0f796a35'] = 'Startseiten-Text-Editor';
$_MODULE['<{editorial}prestashop>editorial_d02076897ed05399e22a0597404924ad'] = 'Ein Texteditor-Modul für Ihre Startseite';
$_MODULE['<{editorial}prestashop>editorial_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';
$_MODULE['<{editorial}prestashop>editorial_0245625ee10f9c6c0ed7f50eb1838856'] = 'Haupttitel';
$_MODULE['<{editorial}prestashop>editorial_7496c27605d7ac3462a5dab8ecf1b569'] = 'Erscheint oben auf der Startseite';
$_MODULE['<{editorial}prestashop>editorial_e1f46be647e598f00eeb0ab62561d695'] = 'Untertitel';
$_MODULE['<{editorial}prestashop>editorial_bf75f228011d1443c4ea7aca23c3cff2'] = 'Einleitungstext';
$_MODULE['<{editorial}prestashop>editorial_930919b6f854a62e62401e3e76377cc1'] = 'Text Ihrer Wahl, zum Beispiel erläutern Sie Ihre Mission, heben ein neues Produkt hervor oder beschreiben ein aktuelles Ereignis';
$_MODULE['<{editorial}prestashop>editorial_78587f196180054fcb797d40f4a86f10'] = 'Logo der Startseite';
$_MODULE['<{editorial}prestashop>editorial_28d74ee805e3a162047d8f917b74dcb3'] = 'Startseitenlogo-Link';
$_MODULE['<{editorial}prestashop>editorial_98039e8f2a0d93fc0fff503f9166f59b'] = 'Startseitenlogo Untertitel';
$_MODULE['<{editorial}prestashop>editorial_c9cc8cce247e49bae79f15173ce97354'] = 'Speichern';
$_MODULE['<{editorial}prestashop>editorial_7fc8b5e7597368c070f5bc87c719dcc1'] = 'Sie können diese Handlung nicht ausführen';
$_MODULE['<{editorial}prestashop>editorial_07b8c09e490f7afbdcfa9cd5bfcfd4a9'] = 'Ein Fehler trat beim Hochladen des Bilds auf.';
$_MODULE['<{editorial}prestashop>editorial_462390017ab0938911d2d4e964c0cab7'] = 'Einstellungen erfolgreich aktualisiert';
